/**@file  CoverSeparator.hpp
 * @brief  Separator for Cover Inequalities
 * @author Luigi De Giovanni
 */

#ifndef COVERSEPARATOR_H
#define COVERSEPARATOR_H

//#define L_DEBUG

#include <vector>
#include <iostream>

#include <scip/scip.h>
#include <scip/scipdefplugins.h>

namespace scipMeMOC
{
   /**@class CSSlave
    * @brief solver class for the LP relaxation of CS slave problem
    *
    *  this class implements a pattern generator for the LP relaxation of CS1D master problem, which will be solved using SCIP
    */
   class CoverSeparator
   {
   private:

      /** @brief pointer to scip structure */
      SCIP * _scip;

      /** @brief one variable for each item/width */
      std::vector<SCIP_VAR *> _y;

      /** @brief KP constraint */
      SCIP_CONS * _cons;
      
   public:
      /** @brief constructs the slave programming model (KP)
       */
     CoverSeparator( const std::vector<double> & KPvar, const std::vector<double> & weight, const double & capacity );

      /** @brief destructor */
     ~CoverSeparator();

      void solve(void); ///< solves the slave problem using SCIPsolve

      /** @brief display the solution
       *
       * a simplex ASCII output function to display the solution of the slave problem
       * @param[in,out] out ostream class for output(default cout)
       */
      void display(std::ostream & out = std::cout);
      void displayItems(std::ostream & out = std::cout);
      
      SCIP_Real getSolution ( std::vector<double> & varSol );
      
      SCIP * getScipPtr ( void )  { return _scip; }
   };
}
#endif

